@@ -429,7 +429,7 @@ class DirectoryLayer(Directory):
                                  limit=1):
             prev_prefix = self._node_subspace.unpack(k)[0]
             if key.startswith(prev_prefix):
-                return Subspace(rawPrefix=k)  # self._node_subspace[prev_prefix]
+                return self._node_with_prefix(prev_prefix)
         return None
 
     def _node_with_prefix(self, prefix):
