@@ -25,6 +25,8 @@ NetworkOption = {
     "local_address" : (10, "Deprecated", type(''), "IP:PORT"),
     "cluster_file" : (20, "Deprecated", type(''), "path to cluster file"),
     "trace_enable" : (30, "Enables trace output to a file in a directory of the clients choosing", type(''), "path to output directory (or NULL for current working directory)"),
+    "trace_roll_size" : (31, "Sets the maximum size in bytes of a single trace output file. This value should be in the range ``[0, INT64_MAX]``. If the value is set to 0, there is no limit on individual file size. The default is a maximum size of 10,485,760 bytes.", type(0), "max size of a single trace output file"),
+    "trace_max_logs_size" : (32, "Sets the maximum size of a all the trace output files put together. This value should be in the range ``[0, INT64_MAX]``. If the value is set to 0, there is no limit on the total size of the files. The default is a maximum size of 104,857,600 bytes. If the default roll size is used, this means that a maximum of 10 trace files will be written at a time.", type(0), "max total size of trace files"),
     "knob" : (40, "Set internal tuning or debugging knobs", type(''), "knob_name=knob_value"),
     "TLS_plugin" : (41, "Set the TLS plugin to load. This option, if used, must be set before any other TLS options", type(''), "file path or linker-resolved name"),
     "TLS_cert_bytes" : (42, "Set the certificate chain", type(b''), "certificates"),
@@ -58,11 +60,16 @@ TransactionOption = {
     "durability_dev_null_is_web_scale" : (130, "", type(None), None),
     "priority_system_immediate" : (200, "Specifies that this transaction should be treated as highest priority and that lower priority transactions should block behind this one. Use is discouraged outside of low-level tools", type(None), None),
     "priority_batch" : (201, "Specifies that this transaction should be treated as low priority and that default priority transactions should be processed first. Useful for doing batch work simultaneously with latency-sensitive work", type(None), None),
-    "initialize_new_database" : (300, "This is a write-only transaction which sets the initial configuration", type(None), None),
+    "initialize_new_database" : (300, "This is a write-only transaction which sets the initial configuration. This option is designed for use by database system tools only.", type(None), None),
     "access_system_keys" : (301, "Allows this transaction to read and modify system keys (those that start with the byte 0xFF)", type(None), None),
+    "read_system_keys" : (302, "Allows this transaction to read system keys (those that start with the byte 0xFF)", type(None), None),
     "debug_dump" : (400, "", type(None), None),
+    "debug_retry_logging" : (401, "", type(''), "Optional transaction name"),
     "timeout" : (500, "Set a timeout in milliseconds which, when elapsed, will cause the transaction automatically to be cancelled. Valid parameter values are ``[0, INT_MAX]``. If set to 0, will disable all timeouts. All pending and any future uses of the transaction will throw an exception. The transaction can be used again after it is reset. Like all transaction options, a timeout must be reset after a call to onError. This behavior allows the user to make the timeout dynamic.", type(0), "value in milliseconds of timeout"),
     "retry_limit" : (501, "Set a maximum number of retries after which additional calls to onError will throw the most recently seen error code. Valid parameter values are ``[-1, INT_MAX]``. If set to -1, will disable the retry limit. Like all transaction options, the retry limit must be reset after a call to onError. This behavior allows the user to make the retry limit dynamic.", type(0), "number of times to retry"),
+    "max_retry_delay" : (502, "Set the maximum amount of backoff delay incurred in the call to onError if the error is retryable. Defaults to 1000 ms. Valid parameter values are ``[0, INT_MAX]``. Like all transaction options, the maximum retry delay must be reset after a call to onError. If the maximum retry delay is less than the current retry delay of the transaction, then the current retry delay will be clamped to the maximum retry delay.", type(0), "value in milliseconds of maximum delay"),
+    "snapshot_ryw_enable" : (600, "Snapshot read operations will see the results of writes done in the same transaction.", type(None), None),
+    "snapshot_ryw_disable" : (601, "Snapshot read operations will not see the results of writes done in the same transaction.", type(None), None),
 }
 
 StreamingMode = {
@@ -83,6 +90,8 @@ MutationType = {
     "bit_or" : (7, "Performs a bitwise ``or`` operation.  If the existing value in the database is not present or shorter than ``param``, it is first extended to the length of ``param`` with zero bytes.  If ``param`` is shorter than the existing value in the database, the existing value is truncated to match the length of ``param``.", type(b''), "value with which to perform bitwise or"),
     "xor" : (8, "Deprecated", type(b''), "value with which to perform bitwise xor"),
     "bit_xor" : (8, "Performs a bitwise ``xor`` operation.  If the existing value in the database is not present or shorter than ``param``, it is first extended to the length of ``param`` with zero bytes.  If ``param`` is shorter than the existing value in the database, the existing value is truncated to match the length of ``param``.", type(b''), "value with which to perform bitwise xor"),
+    "max" : (12, "Performs a little-endian comparison of byte strings. If the existing value in the database is not present or shorter than ``param``, it is first extended to the length of ``param`` with zero bytes.  If ``param`` is shorter than the existing value in the database, the existing value is truncated to match the length of ``param``. The larger of the two values is then stored in the database.", type(b''), "value to check against database value"),
+    "min" : (13, "Performs a little-endian comparison of byte strings. If the existing value in the database is not present or shorter than ``param``, it is first extended to the length of ``param`` with zero bytes.  If ``param`` is shorter than the existing value in the database, the existing value is truncated to match the length of ``param``. The smaller of the two values is then stored in the database.", type(b''), "value to check against database value"),
 }
 
 ConflictRangeType = {
