@@ -195,9 +195,9 @@ def transactional(*tr_args, **tr_kwargs):
             tr = largs[index] = args[index].create_transaction()
 
             committed = False
-            retries = 0
-            start = datetime.datetime.now()
-            last = start
+            #retries = 0
+            #start = datetime.datetime.now()
+            #last = start
 
             while not committed:
                 try:
@@ -207,19 +207,15 @@ def transactional(*tr_args, **tr_kwargs):
                 except FDBError as e:
                     tr.on_error(e.code).wait()
 
-                now = datetime.datetime.now()
-                td = now - last
-                elapsed = (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / float(10**6)
-                if elapsed >= 1:
-                    # SOMEDAY: it would be nice to provide more
-                    # information than just the undecorated
-                    # function name, but that doesn't seem to be
-                    # non-trivial
-                    td = now - start
-                    print ('fdb WARNING: long transaction (%gs elapsed in transactional function \'%s\' (%d retries, %s))' % (elapsed, func.__name__, retries, committed and 'committed' or 'not yet committed'))
-                    last = now
+                #now = datetime.datetime.now()
+                #td = now - last
+                #elapsed = (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / float(10**6)
+                #if elapsed >= 1:
+                    #td = now - start
+                    #print ('fdb WARNING: long transaction (%gs elapsed in transactional function \'%s\' (%d retries, %s))' % (elapsed, func.__name__, retries, committed and 'committed' or 'not yet committed'))
+                    #last = now
 
-                retries += 1
+                #retries += 1
 
             return ret
 
@@ -1005,8 +1001,16 @@ elif platform.system() == 'Linux':
     capi_name = 'libfdb_c.so'
 elif platform.system() == 'Darwin':
     capi_name = 'libfdb_c.dylib'
+elif sys.platform == 'win32':
+    capi_name = 'fdb_c.dll'
+elif sys.platform.startswith('cygwin'):
+    capi_name = 'fdb_c.dll'
+elif sys.platform.startswith('linux'):
+    capi_name = 'libfdb_c.so'
+elif sys.platform == 'darwin':
+    capi_name = 'libfdb_c.dylib'
 else:
-    raise Exception("Platform %s is not supported by the FoundationDB API!" % platform.system())
+    raise Exception("Platform (%s) %s is not supported by the FoundationDB API!" % (sys.platform, platform.system()))
 this_dir = os.path.dirname(__file__)
 
 # Preferred installation: The C API library or a symbolic link to the
@@ -1252,7 +1256,10 @@ def init(event_model=None):
         try:
             class NetworkThread(threading.Thread):
                 def run(self):
-                    _capi.fdb_run_network()
+                    try:
+                        _capi.fdb_run_network()
+                    except FDBError as e:
+                        sys.stderr.write('Unhandled error in FoundationDB network thread: %s\n' % e)
                     # print('Network stopped')
 
             _network_thread = NetworkThread()
